package com.jqtx.windows.job;

import com.alibaba.fastjson2.JSON;
import com.jqtx.windows.component.LoanPlanComponent;
import com.jqtx.windows.component.SyncBuildComponent;
import com.jqtx.windows.component.config.Contant;
import com.jqtx.windows.component.config.FeignUrlConfig;
import com.jqtx.windows.component.model.LoanPlanModel;
import com.jqtx.windows.component.tsmodel.AddCaseRequest;
import com.jqtx.windows.service.SyncDataService;
import com.jqtx.windows.web.response.JsonResult;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.MessageFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * @Description: 重新推送案件(重试机制推送)
 * @Date: 2019/12/04 10:55
 */
@Component
@Slf4j
public class SyncRetryJob {

    @Autowired
    private FeignUrlConfig feignUrlConfig;
    @Autowired
    private SyncDataService syncDataService;
    @Autowired
    private LoanPlanComponent loanPlanComponent;
    @Autowired
    private SyncBuildComponent syncBuildComponent;

    @XxlJob(value = "syncRetryJobHandler")
    private void process() {
        String param = XxlJobHelper.getJobParam();
        try {
            LocalDateTime executeStartTime = LocalDateTime.now();
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
            log.info("任务开始时间-[{}]", executeStartTime.format(formatter));
            log.info("需要重新推送案件处理开始...");
            Long li1 = System.currentTimeMillis();
            List<LoanPlanModel> list = loanPlanComponent.getByLoan(param);
            for (LoanPlanModel planModel : list) {
                sendTs(syncBuildComponent.buildAddCaseRequest(planModel.getPlanNo()));
            }
            Long li2 = System.currentTimeMillis();
            log.info("任务结束时间-[{}]，执行-[{}]", executeStartTime.format(formatter), li2 - li1);
        } catch (Exception e) {
            log.error(MessageFormat.format("需要重新推送案件处理异常:{0}", e.getMessage()), e);
        }
        log.info("需要重新推送案件处理结束...");
    }

    public Boolean sendTs(AddCaseRequest addCaseRequest) {
        String url = feignUrlConfig.getUrl() + Contant.REMIND_URL;
        String body = com.alibaba.fastjson.JSON.toJSONString(addCaseRequest);
        log.info("同步提醒案件到天思请求:{}", body);
        JsonResult<String> synResult = syncDataService.synResult(url, body);
        log.info("同步提醒案件天思返回:{}", synResult);
        if (synResult.isSuccess()) {
            return true;
        }
        return false;

    }



}
